paidiverpy.utils.static.css
===========================

.. py:module:: paidiverpy.utils.static.css

.. autoapi-nested-parse::

   
   Static CSS files for paidiverpy.
















   ..
       !! processed by numpydoc !!


